#!/bin/bash
# Start Waltz package manager containers

set -exou pipefail

# Get script dir
SCRIPT_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

# Set variables. 
# APDOCKER_DOMAIN is set in from the systemd .service file
APLINUX_REGISTRY="aplinux-microsoft.azurecr.io${APDOCKER_DOMAIN}"
AP_TOOLS_DIR="/ap/app/aptools"

# Hide ACR creds from logs
set +x

# Pull a fresh ACR connection config every start
# We'll only capture stdout to ACR_CONNECTION_STRING, which will be empty on failure
ACR_CONNECTION_STRING=$(${AP_TOOLS_DIR}/apsecret_refresh_acr.py)
if [ $? -ne 0 ]
then
    echo "WARNING: Could not grab the most recent connection configuration for ACR."
fi

if [ -z "${ACR_CONNECTION_STRING}" ]
then
    echo "ERROR: Could not read the cached connection configuration for ACR."
    exit -1
fi

# Turn the connection string into an array
ACR_CONFIG=( ${ACR_CONNECTION_STRING} )
ACR_CLIENT_ID="${ACR_CONFIG[0]}"
ACR_CLIENT_KEY="${ACR_CONFIG[1]}"

if [ -z "${ACR_CLIENT_ID}" ] || [ -z "${ACR_CLIENT_KEY}" ]
then
    echo "ERROR: Invalid connection configuration cached for ACR."
    exit -1
fi

set -x

# Get the image names and tags from version file. This is the file we update
# when updating apwaltz docker image sets
source ${SCRIPT_DIR}/docker-images.ver

# TODO: Move this to the service manager to pull and restart waltz with new version. Don't leave it here.

APWALTZ_IMAGE="aplinux-microsoft.azurecr.io${APDOCKER_DOMAIN}/apwaltz:${AP_WALTZ_IMAGE_TAG}"
ETCD_IMAGE="aplinux-microsoft.azurecr.io${APDOCKER_DOMAIN}/quay.io/coreos/etcd:${AP_ETCD_IMAGE_TAG}"

# Find if the version specified is already available locally. If not available, login and pull
if [[ "$(docker images -q ${ETCD_IMAGE} 2> /dev/null)" == "" || "$(docker images -q ${APWALTZ_IMAGE} 2> /dev/null)" == "" ]]; then
    set +x
    # Login to APLinux ACR registry
    docker login -u ${ACR_CLIENT_ID} -p ${ACR_CLIENT_KEY} ${APLINUX_REGISTRY}
    set -x

    # Pull the images specified
    docker-compose -f ${SCRIPT_DIR}/docker-compose.yml pull
fi

# Just in case the containers were stopped but not removed (happens during a HardReboot),
# remove the old containers. The old containers hold a lock on the names that we'll need
# to get things up and running again. Ignoring errors because this is a "best effort"
# cleanup and the error message for failing to cleanup is very specific.
! docker stop ap_waltz > /dev/null 2>&1
! docker stop ap_etcd > /dev/null 2>&1
! docker rm -f ap_waltz > /dev/null 2>&1
! docker rm -f ap_etcd > /dev/null 2>&1

# Get the containers up
# Start etcd first in the background, sometimes health check from waltz
# will fail if etcd has not started up completely.
docker-compose -f ./docker-compose.yml up -d etcd0
docker-compose -f ./docker-compose.yml up --timeout 30
